==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_lms
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Brisa de signatura correspond pas a queu còde...', # MODIF
	'form_pet_confirmation' => 'Volhatz confirmar vòstra signatura:',
	'form_pet_deja_signe' => 'Avetz ja signat queu text.',
	'form_pet_envoi_mail_confirmation' => 'Aura recebretz un e-mail de confirmacion. Per validar vòstra signatura, chau vesitar l’adreiça web mençonada per queste corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avetz demandat de signar la peticion:
@titre@.

Avetz fornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar vòstra signatura, sufís de vos connectar a 
 l’adreiça çai sos (senon se regetará
vòstra demanda): 
    @url@


Mercés per vòstra participacion
',
	'form_pet_nom_site2' => 'Nom de vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problema tecnic, las signaturas son temporàriament ’restadas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validada. Apareisserá subre lo sit dès l’actualizacion que ven. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja queu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avetz indicada es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenetz un sit, o podetz marcar çai sos',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Responsa a l’article'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=oc_lms
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_activer_petition' => 'Activar la peticion',
	'bouton_radio_pas_petition' => 'Brisa de peticion',
	'bouton_radio_petition_activee' => 'Peticion activada',
	'bouton_radio_supprimer_petition' => 'Suprimir la peticion',

	// F
	'form_pet_adresse_site' => 'Adreiça de vòstre sit', # MODIF
	'form_pet_aucune_signature' => 'Brisa de signatura correspond pas a queu còde...', # MODIF
	'form_pet_confirmation' => 'Volhatz confirmar vòstra signatura:',
	'form_pet_deja_signe' => 'Avetz ja signat queu text.',
	'form_pet_envoi_mail_confirmation' => 'Aura recebretz un e-mail de confirmacion. Per validar vòstra signatura, chau vesitar l’adreiça web mençonada per queste corrier.', # MODIF
	'form_pet_mail_confirmation' => 'Bonjorn,

avetz demandat de signar la peticion:
@titre@.

Avetz fornidas las informacions seguentas:
    Nom: @nom_email@
    Sit: @nom_site@ - @url_site@


IMPORTANT...
Per validar vòstra signatura, sufís de vos connectar a 
 l’adreiça çai sos (senon se regetará
vòstra demanda): 
    @url@


Mercés per vòstra participacion
',
	'form_pet_nom_site2' => 'Nom de vòstre sit web', # MODIF
	'form_pet_probleme_technique' => 'Problema tecnic, las signaturas son temporàriament ’restadas.',
	'form_pet_signature_validee' => 'Vòstra signatura es validada. Apareisserá subre lo sit dès l’actualizacion que ven. Mercés!',
	'form_pet_site_deja_enregistre' => 'Ja queu sit es registrat',
	'form_pet_url_invalide' => 'L’URL qu’avetz indicada es pas valida.',
	'form_pet_votre_email' => 'Vòstra adreiça e-mail',
	'form_pet_votre_nom' => 'Vòstre nom o pseudonim', # MODIF
	'form_pet_votre_site' => 'Se tenetz un sit, o podetz marcar çai sos',

	// I
	'info_adresse_email' => 'ADREIÇA E-MAIL:',
	'info_site_web' => 'SIT WEB:',

	// L
	'lien_reponse_article' => 'Responsa a l’article'
);

?>
